@@ -323,18 +323,21 @@ class sqlobj(object):
 		self.add_frame(key, value)
 
 	def drop_table(self, table_name, backup=True):
+		table_names = list(self.table_names())
+		backup_table_data = self[table_name] if backup and table_name in table_names else None
+
 		just_enter = False
 		if self.exists is None:
 			just_enter = True
 			self.just_enter()
 
-		if table_name in self.table_names():
+		if table_name in table_names:
 			if backup:
-				self[table_name].to_csv(".backup_{0}.csv".format(table_name))
+				backup_table_data.to_csv(".backup_{0}.csv".format(table_name))
 
 			if just_enter:
 				current_cursor = self.connection.cursor()
-				current_cursor.execute("DROP table IF EXISTS {0};".format({0}))
+				current_cursor.execute("DROP table IF EXISTS {0};".format(table_name))
 				current_cursor = None
 			else:
 				try:
